debiased\_sd package
====================

Submodules
----------

debiased\_sd.estimators module
------------------------------

.. automodule:: debiased_sd.estimators
   :members:
   :undoc-members:
   :show-inheritance:

debiased\_sd.utils module
-------------------------

.. automodule:: debiased_sd.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: debiased_sd
   :members:
   :undoc-members:
   :show-inheritance:
